command

package
v0.36.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2026 License: MIT Imports: 40 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AIDatasetCommand added in v0.36.0

type AIDatasetCommand struct {
	InputPath   string
	OutputPath  string
	Verbose     bool
	MaxFiles    int
	Concurrency int
	// contains filtered or unexported fields
}

func NewAIDatasetCommand added in v0.36.0

func NewAIDatasetCommand(inputPath, outputPath string, verbose bool, maxFiles, concurrency int) *AIDatasetCommand

func (*AIDatasetCommand) Execute added in v0.36.0

func (c *AIDatasetCommand) Execute() error

type AnalyzeCommand

type AnalyzeCommand struct {
	Configuration *configuration.Configuration

	FileWatcher *fsnotify.Watcher
	// contains filtered or unexported fields
}

func NewAnalyzeCommand

func NewAnalyzeCommand(configuration *configuration.Configuration, outWriter *bufio.Writer, runners []engine.Engine, isInteractive bool) *AnalyzeCommand

func (*AnalyzeCommand) Execute

func (v *AnalyzeCommand) Execute() error

func (*AnalyzeCommand) ExecuteRunnerAnalysis

func (v *AnalyzeCommand) ExecuteRunnerAnalysis(config *configuration.Configuration) ([]*pb.File, error)

type CICommand added in v0.28.0

type CICommand struct {
	Configuration *configuration.Configuration
	// contains filtered or unexported fields
}

CICommand runs lint and then generates all reports like `analyze --ci`. It returns the lint error (if any) as final status so CI pipelines can fail, but will still generate the reports before exiting.

func NewCICommand added in v0.28.0

func NewCICommand(configuration *configuration.Configuration, outWriter *bufio.Writer, runners []engine.Engine) *CICommand

func (*CICommand) Execute added in v0.28.0

func (c *CICommand) Execute() error

type CleanCommand

type CleanCommand struct {
	Storage *storage.Workdir
}

func NewCleanCommand

func NewCleanCommand(storage *storage.Workdir) *CleanCommand

func (*CleanCommand) Execute

func (v *CleanCommand) Execute() error

type DeployGithubOrganizationCommand added in v0.30.0

type DeployGithubOrganizationCommand struct {
	Organization string
	Token        string
	Branch       string
	WorkflowPath string
	IncludeForks bool
}

func NewDeployGithubOrganizationCommand added in v0.30.0

func NewDeployGithubOrganizationCommand(organization, token, branch, workflowPath string, includeForks bool) *DeployGithubOrganizationCommand

func (*DeployGithubOrganizationCommand) Execute added in v0.30.0

type DeployResult added in v0.30.0

type DeployResult struct {
	RepoName string
	Status   string // "success", "skipped", "error"
	PRNumber int
	Error    string
}

type GitHubContent added in v0.30.0

type GitHubContent struct {
	Name        string `json:"name"`
	Path        string `json:"path"`
	Sha         string `json:"sha"`
	Size        int    `json:"size"`
	URL         string `json:"url"`
	HTMLURL     string `json:"html_url"`
	GitURL      string `json:"git_url"`
	DownloadURL string `json:"download_url"`
	Type        string `json:"type"`
	Content     string `json:"content"`
	Encoding    string `json:"encoding"`
}

type GitHubPullRequest added in v0.30.0

type GitHubPullRequest struct {
	Number  int    `json:"number"`
	State   string `json:"state"`
	Title   string `json:"title"`
	Body    string `json:"body"`
	HTMLURL string `json:"html_url"`
}

type GitHubRef added in v0.30.0

type GitHubRef struct {
	Ref    string `json:"ref"`
	NodeID string `json:"node_id"`
	URL    string `json:"url"`
	Object struct {
		Type string `json:"type"`
		Sha  string `json:"sha"`
		URL  string `json:"url"`
	} `json:"object"`
}

type GitHubRepo added in v0.30.0

type GitHubRepo struct {
	Name          string `json:"name"`
	FullName      string `json:"full_name"`
	DefaultBranch string `json:"default_branch"`
	Archived      bool   `json:"archived"`
	Fork          bool   `json:"fork"`
	Private       bool   `json:"private"`
}

type GithubAsset

type GithubAsset struct {
	Name                 string
	Browser_download_url string
}

type GithubRelease

type GithubRelease struct {
	Assets []GithubAsset
	Name   string
}

type InitConfigurationCommand

type InitConfigurationCommand struct {
}

func NewInitConfigurationCommand

func NewInitConfigurationCommand() *InitConfigurationCommand

func (*InitConfigurationCommand) Execute

func (v *InitConfigurationCommand) Execute() error

type LintCommand added in v0.24.0

type LintCommand struct {
	Configuration *configuration.Configuration
	// contains filtered or unexported fields
}

LintCommand runs the analysis and prints only requirement violations (lint), grouped by file.

func NewLintCommand added in v0.24.0

func NewLintCommand(configuration *configuration.Configuration, outWriter *bufio.Writer, runners []engine.Engine) *LintCommand

func (*LintCommand) Execute added in v0.24.0

func (c *LintCommand) Execute() error

func (*LintCommand) SetVerbose added in v0.24.0

func (c *LintCommand) SetVerbose(v bool)

type RulesetAddCommand

type RulesetAddCommand struct{ Name string }

func NewRulesetAddCommand

func NewRulesetAddCommand(name string) *RulesetAddCommand

func (*RulesetAddCommand) Execute

func (c *RulesetAddCommand) Execute() error

type RulesetListCommand

type RulesetListCommand struct {
}

func NewRulesetListCommand

func NewRulesetListCommand() *RulesetListCommand

func (*RulesetListCommand) Execute

func (c *RulesetListCommand) Execute() error

type RulesetShowCommand

type RulesetShowCommand struct{ Name string }

func NewRulesetShowCommand

func NewRulesetShowCommand(name string) *RulesetShowCommand

func (*RulesetShowCommand) Execute

func (c *RulesetShowCommand) Execute() error

type SelfUpdateCommand

type SelfUpdateCommand struct {
	// contains filtered or unexported fields
}

func NewSelfUpdateCommand

func NewSelfUpdateCommand(currentVersion string) *SelfUpdateCommand

func (*SelfUpdateCommand) Execute

func (v *SelfUpdateCommand) Execute() error

func (*SelfUpdateCommand) GetLatestRelease

func (v *SelfUpdateCommand) GetLatestRelease() (*GithubRelease, error)

type VersionCommand

type VersionCommand struct {
	CurrentVersion string
}

func NewVersionCommand

func NewVersionCommand(currentVersion string) *VersionCommand

func (*VersionCommand) Execute

func (v *VersionCommand) Execute() error

Jump to